bounds..do_rledf_range_summary(x, bounds, na.rm = FALSE, simplify = TRUE, RLEFUN,
FUN.TYPE = c("numeric", "double", "integer", "logical"))bounds is a matrix, the first
two columns are used as as the starts and stops. Names for the ranges are taken from rownames of the matrix. Such a matrix can be
constructed with boundingIndicesByChr.simplify == TRUE, a vector for single view or a matrix
otherwise. When simplify == FALSE, a list of vectors length ncol(x) where each element is of length nrows(bounds).Other views: .do_rledf_views