Learn R Programming

genoset (version 1.24.0)

GenoSet: Create a GenoSet object

Description

This function is the preferred method for creating a new GenoSet object. Users are generally discouraged from calling "new" directly. Any "..." arguments will become part of the assayData slot of the resulting object. "..." can be matrices or DataFrame objects (from IRanges). This function passes control to the "initGenoSet" method which performs argument checking including dimname matching among relevant slots and sets everything to genome order. Genome order can be disrupted by "[" calls and will be checked by methods that require it.

Usage

GenoSet(locData, pData = NULL, annotation = "", assayData = NULL, ...)

Arguments

locData
A GRanges object specifying feature chromosome locations. Rownames are required to match featureNames.
pData
A data frame with rownames matching all data matrices
annotation
character, string to specify chip/platform type
assayData
assayData, usually an environment
...
More matrix or DataFrame objects to include in assayData

Value

A GenoSet object

Examples

Run this code
test.sample.names = LETTERS[11:13]
probe.names = letters[1:10]
gs = GenoSet(
   locData=GRanges(ranges=IRanges(start=1:10,width=1,names=probe.names),seqnames=c(rep("chr1",4),rep("chr3",2),rep("chrX",4))),
   cn=matrix(31:60,nrow=10,ncol=3,dimnames=list(probe.names,test.sample.names)),
   pData=data.frame(matrix(LETTERS[1:15],nrow=3,ncol=5,dimnames=list(test.sample.names,letters[1:5]))),
   annotation="SNP6" )

Run the code above in your browser using DataLab