Learn R Programming

genoset (version 1.24.0)

chrInfo: Get chromosome start and stop positions

Description

Provides a matrix of start, stop and offset, in base numbers for each chromosome.

Usage

chrInfo(object)
"chrInfo"(object)

Arguments

object
A GenoSet object or similar

Value

list with start and stop position, by ordered chr

Examples

Run this code
data(genoset)
  chrInfo(genoset.ds)
  chrInfo(locData(genoset.ds))  # The same

Run the code above in your browser using DataLab