Learn R Programming

genoset (version 1.24.0)

genoPos: Get base positions of features in genome-scale units

Description

Get base positions of array features in bases counting from the start of the genome. Chromosomes are ordered numerically, when possible, then lexically.

Usage

genoPos(object)
"genoPos"(object)

Arguments

object
A GenoSet object or a GenomicRanges object

Value

numeric position of each feature in whole genome units, in original order

Examples

Run this code
data(genoset)
  head(genoPos(genoset.ds))
  head(genoPos(locData(genoset.ds)))  # The same

Run the code above in your browser using DataLab