Learn R Programming

genoset (version 1.24.0)

genoset-datasets: Example GenoSet, BAFSet, and CNSet objects and the data to create them.

Description

Fake LRR, BAF, pData and location data were generated and saved as fake.lrr, fake.cn, fake.baf, fake.pData and locData.rd. These were used to construct the objects genoset.ds, baf.ds, and cn.ds

Usage

data(genoset)

Arguments

Format

fake.lrr
A matrix with some randomly generated LRR (log2ratio copynumber) data
fake.cn
A matrix with some randomly generated LRR (log2ratio copynumber) data
fake.baf
A matrix with some randomly generated BAF (B-Allele Frequency) data
fake.pData
A data.frame of sample annotation to go with fake.lrr and fake.baf
locData.gr
A GRanges object describing the genomic locations of the probes in fake.baf and fake.lrr
genoset.ds
A GenoSet object created with fake.lrr as the "foo" element, locData.rd as the locData, and fake.pData as the phenoData

Fake data generated using rnorm and the like.