Learn R Programming

genoset (version 1.24.0)

genoset-defunct: Defunct genoset features

Description

The CNSet and BAFSet classes are defunct. They only really added getter/setter methods for specific assayDataElements, so they are now redundant with the preferred method of using the assayDataElement name as the third argument to bracket, e.g. x[i, j, "lrr"]. Accordingly BAFSet.to.ExpressionSets is also defunct.

Arguments

Details

Additionally, names, ranges, and space on a GenoSet are also defunct. In an effort to make a consistent API for either RangedData or GRanges in the locData slot, we recommend using chrNames for names and chr for space.