genoPos: Get base positions of features in genome-scale units
Description
Get base positions of array features in bases counting from the start of the
genome. Chromosomes are ordered numerically, when possible, then lexically.
Usage
genoPos(object)
"genoPos"(object)
Arguments
object
A GenoSet object or a GenomicRanges object
Value
numeric position of each feature in whole genome units, in original order