Rdocumentation
powered by
Learn R Programming
genoset (version 1.24.0)
genoset-deprecated: Deprecated genoset features
Description
GenoSet is moving towards using GenomicRanges instead of RangedData. We are also getting rid of dependencies on eSet for a potential switch to an underlying SummarizedExperiment.
Arguments